@@ -99,9 +99,7 @@ sub yaml_load {
     }
     no strict 'refs';
     if (exists $node->{SCALAR}) {
-        if ($YAML::LoadBlessed) {
-            *{"${package}::$name"} = \$node->{SCALAR};
-        }
+        *{"${package}::$name"} = \$node->{SCALAR};
         delete $node->{SCALAR};
     }
     for my $elem (qw(ARRAY HASH CODE IO)) {
@@ -111,9 +109,7 @@ sub yaml_load {
                 delete $node->{IO};
                 next;
             }
-            if ($YAML::LoadBlessed) {
-                *{"${package}::$name"} = $node->{$elem};
-            }
+            *{"${package}::$name"} = $node->{$elem};
             delete $node->{$elem};
         }
     }
@@ -170,12 +166,12 @@ sub yaml_load {
             return sub {};
         }
         else {
-            CORE::bless $code, $class if ($class and $YAML::LoadBlessed);
+            CORE::bless $code, $class if $class;
             return $code;
         }
     }
     else {
-        return CORE::bless sub {}, $class if ($class and $YAML::LoadBlessed);
+        return CORE::bless sub {}, $class if $class;
         return sub {};
     }
 }
@@ -232,7 +228,7 @@ sub yaml_load {
     $flags =~ s/^\^//;
     my $sub = _QR_TYPES->{$flags} || sub { qr{$_[0]} };
     my $qr = &$sub($re);
-    bless $qr, $class if (length $class and $YAML::LoadBlessed);
+    bless $qr, $class if length $class;
     return $qr;
 }
 
